package tesuji.games.general;

import java.util.Vector;

/**
 	Convenience class used to delegate calls to concerning BoardChanges.
 	Any class that sends BoardChanges can use a member of this class to
 	delegate to.

 	<br><br>Creation date: (17-May-01 2:57:38 PM)<br><br>

	Product: Tesuji Software Go Library.<br><br>

	<font color="#CC6600"><font size=-1>
	Copyright (c) 2001 Tesuji Software B.V.<br>
	All rights reserved.<br><br>

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the
	"Software"), to deal in the Software without restriction, including
	without limitation the rights to use, copy, modify, merge, publish,
	distribute, and/or sell copies of the Software, and to permit persons
	to whom the Software is furnished to do so, provided that the above
	copyright notice(s) and this permission notice appear in all copies of
	the Software and that both the above copyright notice(s) and this
	permission notice appear in supporting documentation.<br><br>

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
	COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
	IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
	CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.<br><br>

	Except as contained in this notice, the name of a Tesuji Software
	shall not be used in advertising or otherwise to promote the sale, use
	or other dealings in this Software without prior written authorization
	of Tesuji Software.<br><br>
	<font color="#00000"><font size=+1>

	@author: Mark Boon
*/
public class BoardChangeSupport
{
	private Vector eventListeners = new Vector();

	/**
	 * GoBoardChangeSupport constructor comment.
	 */
	public BoardChangeSupport()
	{
	    super();
	}
    
	public void addBoardChangeListener(BoardChangeListener l)
	{
		if (eventListeners==null)
			eventListeners = new Vector();

		if (!eventListeners.contains(l))
			eventListeners.addElement(l);
	}

	public boolean hasListeners()
	{
		return (eventListeners!=null);
	}

	public void removeBoardChangeListener(BoardChangeListener l)
	{
		eventListeners.removeElement(l);

		if (eventListeners.size()==0)
			eventListeners = null;
	}

	public void sendBoardChange(int x, int y, byte value, byte oldValue)
	{
		if (eventListeners==null)
			return;

		int size = eventListeners.size();
		for (int i=0; i<size; i++)
		{
			BoardChangeListener l = (BoardChangeListener) eventListeners.elementAt(i);
			l.changeBoard(x,y,value,oldValue);
		}	
	}
}