package tesuji.games.go;

import java.util.Stack;

import tesuji.games.general.Cursor;

/**
 	Abstract class to define a cursor for the go-game.

 	<br><br>Creation date: (09-May-01 1:11:21 PM)<br><br>

	Product: Tesuji Software Go Library.<br><br>

	<font color="#CC6600"><font size=-1>
	Copyright (c) 2001 Tesuji Software B.V.<br>
	All rights reserved.<br><br>

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the
	"Software"), to deal in the Software without restriction, including
	without limitation the rights to use, copy, modify, merge, publish,
	distribute, and/or sell copies of the Software, and to permit persons
	to whom the Software is furnished to do so, provided that the above
	copyright notice(s) and this permission notice appear in all copies of
	the Software and that both the above copyright notice(s) and this
	permission notice appear in supporting documentation.<br><br>

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
	COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
	IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
	CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.<br><br>

	Except as contained in this notice, the name of a Tesuji Software
	shall not be used in advertising or otherwise to promote the sale, use
	or other dealings in this Software without prior written authorization
	of Tesuji Software.<br><br>
	<font color="#00000"><font size=+1>

	@author: Mark Boon
*/
abstract class GoCursor
	implements Cursor
{
	// This is the location relative to which the cursor moves.
	protected int start;

	// This array contains the coordinates to iterate over.
	protected int[] path;

	// This is the current position of the cursor on the path.
	protected int currentIndex;

	 // This is the stack that owns the object when it gets
	 // created and to which it gets recycled after use.
	private Stack owner;

	public final boolean continues()
	{
		return (currentIndex>0);
	}

	public final int next()
	{
		return start+path[--currentIndex];
	}

	public void start()
	{
		currentIndex = path.length;
	}

	final void setStart(int startPosition)
	{
		start = startPosition;
	}

	public GoCursor(int startPosition, Stack stack)
	{
		start = startPosition;
		owner = stack;
	}

	public void recycle()
	{
		if (owner!=null)
			owner.push(this);
	}
}